@@ -78,13 +78,7 @@ _RED_LOGGER = getLogger("red")
 _LOCK = threading.Lock()
 
 
-def alru_cache(
-    fn=None,
-    maxsize=128,
-    typed=False,
-    *,
-    cache_exceptions=True,
-):
+def alru_cache(fn=None, maxsize=128, typed=False, *, cache_exceptions=True, ignore_kwargs=None):
     def wrapper(fn):
         _origin = unpartial(fn)
 
@@ -125,9 +119,7 @@ def alru_cache(
             task.add_done_callback(functools.partial(_done_callback, fut))
             wrapped.tasks.add(task)
             task.add_done_callback(wrapped.tasks.remove)
-            if fn.__name__ == "get_or_create":
-                wrapped._cache[key] = fut
-
+            wrapped._cache[key] = fut
             if maxsize is not None and len(wrapped._cache) > maxsize:
                 wrapped._cache.popitem()
 
@@ -485,13 +477,9 @@ class PlayerQueue(asyncio.Queue[T]):
                 await putter
             except BaseException:
                 putter.cancel()  # Just in case putter is not done yet.
-                try:
+                with contextlib.suppress(ValueError):
                     # Clean self._putters from canceled putters.
                     self._putters.remove(putter)
-                except ValueError:
-                    # The putter could be removed from self._putters by a
-                    # previous get_nowait call.
-                    pass
                 if not self.full() and not putter.cancelled():
                     # We were woken up by get_nowait(), but can't take
                     # the call.  Wake up the next in line.
@@ -522,17 +510,10 @@ class PlayerQueue(asyncio.Queue[T]):
             try:
                 await getter
             except BaseException:
-                getter.cancel()  # Just in case getter is not done yet.
-                try:
-                    # Clean self._getters from canceled getters.
+                getter.cancel()
+                with contextlib.suppress(ValueError):
                     self._getters.remove(getter)
-                except ValueError:
-                    # The getter could be removed from self._getters by a
-                    # previous put_nowait call.
-                    pass
                 if not self.empty() and not getter.cancelled():
-                    # We were woken up by put_nowait(), but can't take
-                    # the call.  Wake up the next in line.
                     self._wakeup_next(self._getters)
                 raise
         return self.get_nowait(index=index)
